Ruletable

Struct Ruletable 

pub struct Ruletable { /* private fields */ }
Internal Ruletable representation.

Usage

The Ruletable is typically constructed using Ruletable::from_file or Ruletable::from_multiline_string and then passed to reach.

Implementations

Source

impl Ruletable

pub fn from_file(filename: &str) -> Result<Ruletable, ReadRuletableError>

Constructs a Ruletable from the contents of a file.

Errors

Returns an error if the file cannot be read or if parsing fails.

pub fn from_multiline_string( ruletable_str: &str, ) -> Result<Ruletable, ReadRuletableError>

Constructs a Ruletable from a multi-line string.

Errors

Returns an error if parsing the input string fails.